Twinkerer creates post for tinkerer from user tweete timeline.
==============================================================

Twinkerer is tinkerer small extension to use twitter api.


Please see the details `README_ja.rst <./README_ja.rst>`_ written in Japanese.
